Installation — django-nomadblog 0.5 documentation

### Navigation

- index
- previous |
- django-nomadblog 0.5 documentation »

# Installation

The package is listed in the Python Package Index. You can use your favorite package manager like `easy_install` or `pip`:

    pip install django-nomadblog

Or, you can clone the latest development code from its repository:

    git clone git@github.com:nabucosound/django-nomadblog.git

### Navigation

- index
- previous |
- django-nomadblog 0.5 documentation »